@@ -53,7 +53,7 @@
 #define FIELD_SIZE_Y 6
 
 // Constructor
-KWin4Doc::KWin4Doc(QWidget *parent) : KGame(1234,parent), pView(0), mHintProcess(0)
+KWin4Doc::KWin4Doc(QWidget *parent) : KGame(1234,parent), pView(), mHintProcess()
 {
   mStatus = new Score(parent);
 
@@ -229,7 +229,7 @@ void KWin4Doc::endGame(TABLE mode)
   // TODO pView->clearError();
   pView->endGame();
 
-  // Increase game statisics
+  // Increase game statistics
   KWin4Player *yellow=getPlayer(Yellow);
   KWin4Player *red=getPlayer(Red);
   switch(mode)
@@ -930,7 +930,7 @@ void KWin4Doc::setPlayedBy(int col, KGameIO::IOMode io)
     bool myTurn = player->myTurn();
     player->setTurn(false); // turn of move
     mPlayedBy[col]=io;
-    player->removeGameIO(0); // remove all IO's
+    player->removeGameIO(); // remove all IO's
     createIO(player,io);
     player->setTurn(myTurn); // turn on move
   }
@@ -1029,7 +1029,7 @@ void KWin4Doc::prepareAITurn(QDataStream& stream, bool b, KGameIO* input, bool*
 }
 
 // Sends the current game status to the computer player
-// Careful: The data needs to be exatcly the same as the computer
+// Careful: The data needs to be exactly the same as the computer
 // player reading on the other side
 void KWin4Doc::prepareGameMessage(QDataStream& stream, qint32 pl)
 {
@@ -1050,7 +1050,7 @@ void KWin4Doc::prepareGameMessage(QDataStream& stream, qint32 pl)
   stream << (qint32)learning;
 
   // Where to save the learn cache
-  QString learnPath =  QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + "kwin4";
+  QString learnPath =  QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + QStringLiteral("kwin4");
 
   stream << learnPath;
 
@@ -1180,11 +1180,11 @@ KWin4Player* KWin4Doc::getPlayer(COLOUR col)
      return (KWin4Player *)(*it);
  }
  qCCritical(KFOURINLINE_LOG) << "SERIOUS ERROR: Cannot find player with colour" << col << ".  CRASH imminent";
- return 0;
+ return nullptr;
 }
 
 
-// We create a process which calulcates a computer move which is shown as hint to the player.
+// We create a process which calculates a computer move which is shown as hint to the player.
 void KWin4Doc::calculateHint()
 {
   // We allocate the hint process only if it is needed
@@ -1322,7 +1322,7 @@ void KWin4Doc::gamePropertyChanged(KGamePropertyBase* prop, KGame* /* me */)
 
 
 // This is an overwritten function of KGame which is called
-// when a game is loaded. This can either be via a networ
+// when a game is loaded. This can either be via a network
 // connect or via a real load from file
 bool KWin4Doc::loadgame(QDataStream &stream,bool network,bool reset)
 {
@@ -1380,8 +1380,8 @@ void KWin4Doc::newPlayersJoin(KGamePlayerList* /*oldList*/,KGamePlayerList* newL
   
   KWin4Player *yellow=getPlayer(Yellow);
   KWin4Player *red=getPlayer(Red);
-  // Take the master player with the higher priority. Prioirty is set
-  // be the network dialog
+  // Take the master player with the higher priority. Priority is set
+  // by the network dialog
   if (yellow->networkPriority()>red->networkPriority())
   {
     // Deactivate the lower one 
